@@ -1,5 +1,5 @@
 package Net::SPID::SAML;
-$Net::SPID::SAML::VERSION = '0.14';
+$Net::SPID::SAML::VERSION = '0.15';
 use Moo;
 
 use Carp;
@@ -123,7 +123,7 @@ sub parse_logoutresponse {
     my $r = Net::SPID::SAML::In::LogoutResponse->new(
         _spid       => $self,
         base64      => $payload,
-        URL         => $url,
+        url         => $url,
     );
     
     # Validate response. This will throw an exception in case of failure.
@@ -138,7 +138,7 @@ sub parse_logoutrequest {
     my $r = Net::SPID::SAML::In::LogoutRequest->new(
         _spid       => $self,
         base64      => $payload,
-        URL         => $url,
+        url         => $url,
     );
     
     # Validate request. This will throw an exception in case of failure.
@@ -233,7 +233,7 @@ Net::SPID::SAML
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
