@@ -1,5 +1,5 @@
 package Net::SPID::SAML::In::Base;
-$Net::SPID::SAML::In::Base::VERSION = '0.14';
+$Net::SPID::SAML::In::Base::VERSION = '0.15';
 use Moo;
 
 extends 'Net::SPID::SAML::ProtocolMessage';
@@ -48,8 +48,8 @@ sub BUILDARGS {
         }
         my $payload = $u->query_param('SAMLRequest') // $u->query_param('SAMLResponse');
         $payload = decode_base64($payload);
-        rawinflate \$payload => \$payload;
-        $args{xml} //= $payload;
+        rawinflate \$payload => \my $deflated;
+        $args{xml} = $deflated;
         $args{relaystate} //= $u->query_param('RelayState');
     }
     
@@ -100,10 +100,17 @@ sub _validate_post_or_redirect {
         
         # verify the response
         my $SigAlg = $u->query_param('SigAlg');
-        croak "Unsupported SigAlg: $SigAlg"
-             unless $SigAlg eq 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha256';
-    
         my $pubkey = Crypt::OpenSSL::RSA->new_public_key($self->_idp->cert->pubkey);
+        if ($SigAlg eq 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha256') {
+            $pubkey->use_sha256_hash;
+        } elsif ($SigAlg eq 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha384') {
+            $pubkey->use_sha384_hash;
+        } elsif ($SigAlg eq 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha512') {
+            $pubkey->use_sha512_hash;
+        } else {
+            croak "Unsupported SigAlg: $SigAlg";
+        }
+        
         my $sig = decode_base64($u->query_param_delete('Signature'));
         $pubkey->verify($u->query, $sig)
             or croak "Signature verification failed";
@@ -128,7 +135,7 @@ Net::SPID::SAML::In::Base
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =for Pod::Coverage *EVERYTHING*
 
